﻿using System.Collections;
using UnityEngine.UI;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

public class CharacterMovement : MonoBehaviour {

    public float speed;
    public float jump;
    public float fall;
    public AudioClip[] walkS;
    public AudioClip[] jumpS;
    public AudioClip[] groundS;
    public AudioClip[] barkS;

    private bool walking = false;
    private AudioClip outputSound;
    private AudioSource audioComponent;

    private float fireSpellStart = 0f;
    private float fireSpellCooldown = 2f;

    bool isInAir = false;
    bool createWave = false;
    string waveType;
    private bool lookingLeft = false;

    private GameController gameController;

    private Animator m_Anim;

    private void Awake()
    {
        m_Anim = GetComponent<Animator>();
        audioComponent = GetComponent<AudioSource>();
    }
    // Use this for initialization
    void Start() {

        gameController = (GameController)GameObject.Find("GameController").GetComponent(typeof(GameController));
    }
    IEnumerator Bark(string type)
    {
        yield return new WaitForSeconds(0.3f);
        int random4 = Random.Range(0, barkS.Length);
        outputSound = barkS[random4];
        print(outputSound);
        audioComponent.PlayOneShot(outputSound);
        CreateWave(type);
        m_Anim.SetBool("Bark", false);
    }
    IEnumerator Jump()
    {
        yield return new WaitForSeconds(0.3f);
        this.GetComponent<Rigidbody2D>().AddForce(new Vector2(0, jump), ForceMode2D.Impulse);
        m_Anim.SetBool("JumpL", false);

    }
    public void Step(int i)
    {

        int random5 = Random.Range(0, walkS.Length);

        AudioSource.PlayClipAtPoint(walkS[random5], transform.position);
    }

    void Update()
    {


    }


    // Update is called once per frame
    void FixedUpdate() {
        float step = speed * Time.deltaTime;

        m_Anim.SetBool("WalkL", false);
        if (Input.GetKey("a") || Input.GetKey("joystick button 4"))

        {
            walking = true;
            transform.localScale = new Vector3(0.33f, 0.33f, 0.33f);
            lookingLeft = true;
            m_Anim.SetBool("WalkL", true);
            this.transform.position = Vector3.MoveTowards(transform.position, new Vector3(this.transform.position.x - 1, this.transform.position.y, this.transform.position.z), step);
        }
        if (Input.GetKey("d") || Input.GetKey("joystick button 5")) {
            walking = true;
            m_Anim.SetBool("WalkL", true);
            transform.localScale = new Vector3(-0.33f, 0.33f, 0.33f);
            lookingLeft = false;
            this.transform.position = Vector3.MoveTowards(transform.position, new Vector3(this.transform.position.x + 1, this.transform.position.y, this.transform.position.z), step);
        }

        if (Input.GetKeyDown("w") || Input.GetKey("joystick button 0")) {
            if (!isInAir) {
                int random2 = Random.Range(0, jumpS.Length);
                outputSound = jumpS[random2];
                audioComponent.PlayOneShot(outputSound);

                isInAir = true;
                m_Anim.SetBool("isGround", false);
                StartCoroutine("Jump");
                m_Anim.SetBool("JumpL", true);


            }
        }
		if (Input.GetKeyDown ("s")) {
			if (isInAir) {
				this.GetComponent<Rigidbody2D> ().AddForce (new Vector2 (0, -jump), ForceMode2D.Impulse);
			}
		}

		if (Input.GetKeyDown ("h") || Input.GetKeyDown("joystick button 1"))
        {
            
			if (!isInAir)
            {
                if (Time.time > fireSpellStart + fireSpellCooldown)
                {
                    fireSpellStart = Time.time;
                    m_Anim.SetBool("Bark", true);
                    StartCoroutine("Bark", "Sinusoidal");
                }
			}
		}

		if (Input.GetKeyDown ("j") || Input.GetKeyDown("joystick button 2"))
            {
                
			if (!isInAir)
			{
                if (Time.time > fireSpellStart + fireSpellCooldown)
                {
                    fireSpellStart = Time.time;
                    m_Anim.SetBool("Bark", true);
                    StartCoroutine("Bark", "Cubic");
                }
			}
		}

		if (Input.GetKeyDown ("k") || Input.GetKeyDown("joystick button 3"))
                {
                    
			if (!isInAir)
			{
                if (Time.time > fireSpellStart + fireSpellCooldown)
                {
                    fireSpellStart = Time.time;
                    m_Anim.SetBool("Bark", true);
                    StartCoroutine("Bark", "Triangular");
                }
			}
		}
	}

    void CreateWave(string type)
    {
        gameController.CreateWave(transform, type, lookingLeft);
            
    }


    void OnCollisionEnter2D(Collision2D collision)
    {
		if (collision.gameObject.tag == "Ground") {
            int random3 = Random.Range(0, groundS.Length);
            outputSound = groundS[random3];
            audioComponent.PlayOneShot(outputSound);
            m_Anim.SetBool("isGround", true);
            isInAir = false;

        }
        if (collision.gameObject.name == "MUSIC")
        {
            gameController.ChangeMusic();
        }
		if (collision.gameObject.tag == "Sinusoidal") {
			int random3 = Random.Range(0, groundS.Length);
			outputSound = groundS[random3];
			audioComponent.PlayOneShot(outputSound);
			m_Anim.SetBool("isGround", true);
			isInAir = false;
		}
        

        if (collision.transform.tag == "Cubic")
        {
            Physics2D.IgnoreCollision(collision.collider, this.GetComponent<Collider2D>(), true);
        }

        if (collision.transform.tag == "Diamond")
        {
			Application.Quit ();
	    }

    }
}
