﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class WaveMovement : MonoBehaviour {

    public bool move = true;
    public float speed = 1f;
	public float reduceSpeed = 0.001f;
    public bool reduceScale = false;
    public bool directionX = true; // true = x ; false = -x
	public bool isAmplified = false;

	private float lifeSpan = 0;

	private GameController gameController;

    // Use this for initialization
    void Start()
    {
		gameController = (GameController)GameObject.Find("GameController").GetComponent(typeof(GameController));
    }

    // Update is called once per frame
    void Update()
    {


    }
    void FixedUpdate()
    {
		lifeSpan += 1f;

        if (move)
        {
            if (directionX)
            {
                transform.position = Vector3.MoveTowards(transform.position, transform.position + new Vector3(1f, 0f, 0f), speed / 10);
            }
            else
            {
                transform.position = Vector3.MoveTowards(transform.position, transform.position - new Vector3(1f, 0f, 0f), speed / 10);
            }

            if (reduceScale)
            {
				transform.localScale = new Vector3(Mathf.Lerp(transform.localScale.x, 0, reduceSpeed), Mathf.Lerp(transform.localScale.y, 0, reduceSpeed), Mathf.Lerp(transform.localScale.z, 0, reduceSpeed));
            }
        }

		if (transform.localScale.x < 0.07) {
			Destroy (gameObject);
		}
    }

    void OnTriggerEnter2D(Collider2D other)
    {
		if (other.tag== "DirectionChanger")
		{
			directionX = !directionX;

		}
        if (other.tag== "Border")
        {
			move = false;

        }
        if (other.tag == "Reflect")
        {
            if (directionX)
            {
                directionX = false;
            }
            else
            {
                directionX = true;
            }
        }

		if (other.gameObject.tag == "AmplifierIn") {
			transform.localScale = new Vector3(transform.localScale.x*3, transform.localScale.y*3, transform.localScale.z*3);
			GetComponent<SpriteRenderer> ().color = Color.clear;
			Physics2D.IgnoreCollision(other, this.GetComponent<Collider2D>(), true);
			isAmplified = true;
		}
    }

	void OnCollisionEnter2D(Collision2D  other) 
	{
		checkWaveCollision (other);
		ticTacToe (other);

		if (other.transform.tag == "Glass" && this.tag == "Triangular") {
			if (isAmplified) {
				Destroy (other.gameObject);
				Destroy (gameObject);
			}
		}
	}


	void OnTriggerExit2D(Collider2D  other) 
	{
		if (other.transform.tag == "AmplifierOut") {			
			GetComponent<SpriteRenderer> ().color = Color.white;
		}
	}


	IEnumerator RestoreCollision(float duration, Collision2D other)
	{
		yield return new WaitForSeconds(duration);
		Physics2D.IgnoreCollision(other.collider, this.GetComponent<Collider2D>(), false);
	}

	void ticTacToe(Collision2D other){
		switch (other.gameObject.tag) {
		case "Sinusoidal":
			if (this.tag == "Triangular") {
				Destroy (gameObject);
			}
			break;
		case "Cubic":
			if (this.tag == "Sinusoidal") {
				Destroy (gameObject);
			}
			break;
		case "Triangular":
			if (this.tag == "Cubic") {
				Destroy (gameObject);
			}
			break;
		default:
			break;
		}
	}

	void checkWaveCollision(Collision2D other){
		if (other.gameObject.tag == this.tag && lifeSpan > 100f) {
			if (directionX) {
				gameController.CreateCollisionWave (transform, other.transform, this.tag, directionX);
			}
			Physics2D.IgnoreCollision(other.collider, this.GetComponent<Collider2D>(), true);
			StartCoroutine (RestoreCollision (1f, other));
		}
	}
		
}
